Dojo DnD parent position test

Make sure that all can be dragged nicely.

Remember to check that it works when the window is scrolled!

a

b

c

This list is inside a form: Drag should Not start from top left of screen.

- list 3 item 1
- list 3 item 2
- list 3 item 3

This list is inside a div

- list 5 item 1
- list 5 item 2

This list is inside a div, and the list itself is relative positioned

- list 5 item 1
- list 5 item 2

This list is also inside a form which is relative positioned.

- list 1 item 1
- list 1 item 2
- list 1 item 3

This list is inside a form, which is inside a relative positioned div

- list 2 item 1
- list 2 item 2
- list 2 item 3

This list is inside a relative-postioned form, which is inside an absolute positioned div

- list 4 item 1
- list 4 item 2
- list 4 item 3

a debug conosle inside a relative div

a debug console in body